==> eiffelstudio-18.07.10.1981.tar: F_code/C2/ir92.c <==
/*
 * Code for class IRON_FS_PACKAGE_INFO_DIRECTORY_ITERATOR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ir92.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {IRON_FS_PACKAGE_INFO_DIRECTORY_ITERATOR}.make */
void F109_2672 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("make", 108, Current, 0, 1, 2862);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {IRON_FS_PACKAGE_INFO_DIRECTORY_ITERATOR}.list */
EIF_REFERENCE F109_2675 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {IRON_FS_PACKAGE_INFO_DIRECTORY_ITERATOR}.scan_folder */
void F109_2676 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	struct eif_ex_63 sloc1;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) sloc1.data;
	EIF_BOOLEAN tb1;
	RTLD;
	
	memset (&sloc1.overhead, 0, OVERHEAD + _OBJSIZ_0_0_0_0_0_0_0_0_);
	sloc1.overhead.ov_flags = EO_EXP | EO_STACK;
	RT_DFS(&sloc1.overhead, eif_new_type(68, 0x00).id);
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("scan_folder", 108, Current, 1, 1, 2866);
	RTGC;
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	RTHOOK(2);
	tb1 = F69_2065(RTCW(loc1), arg1);
	if (tb1) {
		RTHOOK(3);
		F109_2677(Current, arg1);
	}
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {IRON_FS_PACKAGE_INFO_DIRECTORY_ITERATOR}.process_directory */
void F109_2677 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("process_directory", 108, Current, 0, 1, 2867);
	RTGC;
	RTHOOK(1);
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_))++;
	RTHOOK(2);
	F108_2667(Current, arg1);
	RTHOOK(3);
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_))--;
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {IRON_FS_PACKAGE_INFO_DIRECTORY_ITERATOR}.process_file */
void F109_2678 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("process_file", 108, Current, 0, 1, 2868);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5913[Dtype(tr1)-599])(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {IRON_FS_PACKAGE_INFO_DIRECTORY_ITERATOR}.path_excluded */
EIF_BOOLEAN F109_2679 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("path_excluded", 108, Current, 0, 1, 2869);
	RTGC;
	RTHOOK(1);
	Result = '\01';
	if (!F108_2669(Current, arg1)) {
		Result = (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_) > ((EIF_INTEGER_32) 2L));
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {IRON_FS_PACKAGE_INFO_DIRECTORY_ITERATOR}.file_excluded */
EIF_BOOLEAN F109_2680 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,Current);
	RTLIU(4);
	
	RTEAA("file_excluded", 108, Current, 0, 1, 2870);
	RTGC;
	RTHOOK(1);
	tr1 = F1322_12796(RTCW(arg1));
	tr2 = RTMS_EX_H(".info",5,1769196143);
	tr2 = F1185_10613(tr2);
	Result = F1188_10719(RTCW(tr1), tr2);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) !Result;
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit92 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C2/ir92.c <==
/*
 * Code for class IRON_FS_PACKAGE_INFO_DIRECTORY_ITERATOR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ir92.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {IRON_FS_PACKAGE_INFO_DIRECTORY_ITERATOR}.make */
void F109_2672 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("make", 108, Current, 0, 1, 2858);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {IRON_FS_PACKAGE_INFO_DIRECTORY_ITERATOR}.scan_folder */
void F109_2676 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	struct eif_ex_63 sloc1;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) sloc1.data;
	EIF_BOOLEAN tb1;
	RTLD;
	
	memset (&sloc1.overhead, 0, OVERHEAD + _OBJSIZ_0_0_0_0_0_0_0_0_);
	sloc1.overhead.ov_flags = EO_EXP | EO_STACK;
	RT_DFS(&sloc1.overhead, eif_new_type(68, 0x00).id);
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("scan_folder", 108, Current, 1, 1, 2862);
	RTGC;
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	RTHOOK(2);
	tb1 = F69_2045(RTCW(loc1), arg1);
	if (tb1) {
		RTHOOK(3);
		F109_2677(Current, arg1);
	}
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {IRON_FS_PACKAGE_INFO_DIRECTORY_ITERATOR}.process_directory */
void F109_2677 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("process_directory", 108, Current, 0, 1, 2863);
	RTGC;
	RTHOOK(1);
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_))++;
	RTHOOK(2);
	F108_2667(Current, arg1);
	RTHOOK(3);
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_))--;
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {IRON_FS_PACKAGE_INFO_DIRECTORY_ITERATOR}.process_file */
void F109_2678 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("process_file", 108, Current, 0, 1, 2864);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R7373[Dtype(RTCW(tr1))-844])(tr1, arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {IRON_FS_PACKAGE_INFO_DIRECTORY_ITERATOR}.path_excluded */
EIF_BOOLEAN F109_2679 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("path_excluded", 108, Current, 0, 1, 2865);
	RTGC;
	RTHOOK(1);
	Result = '\01';
	if (!F108_2669(Current, arg1)) {
		Result = (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_) > ((EIF_INTEGER_32) 2L));
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {IRON_FS_PACKAGE_INFO_DIRECTORY_ITERATOR}.file_excluded */
EIF_BOOLEAN F109_2680 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,Current);
	RTLIU(4);
	
	RTEAA("file_excluded", 108, Current, 0, 1, 2866);
	RTGC;
	RTHOOK(1);
	tr1 = F1333_13005(RTCW(arg1));
	tr2 = RTMS_EX_H(".info",5,1769196143);
	tr2 = F1196_10739(tr2);
	Result = F1198_10811(RTCW(tr1), tr2);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) !Result;
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit92 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
